#[repr(u8)]pub enum Vselect {
VSELECT_B = 0,
VSELECT_A = 1,
}Variants
VSELECT_B = 0
Change the voltage to high voltage range, around 3.0 V
VSELECT_A = 1
Change the voltage to low voltage range, around 1.8 V
Implementations